@@ -273,7 +273,8 @@ static std::string partlist [] = {
     "INFo <s>",            "fills the comments info entry",
     "Humanise Pitch [n]",  "adds a small random pitch change at note_on",
     "Humanise Velocity [n]",  "adds a small random velocity change at note_on",
-    "CLear",               "Sets current instrument level parameters to default.",
+    "CLear [s]",           "sets current instrument level parameters to default.",
+    "",                    "ALL, resets the entire part, including controllers etc.",
     "CHannel <n>",         "MIDI channel (> 32 disables, > 16 note off only)",
     "AFtertouch Chan <s1> [s2]", "Off, Filter (Down) + Peak (Down) + Bend (Down) + Modulation + Volume",
     "AFtertouch Key <s1> [s2]",  "Off, Filter (Down) + Peak (Down) + Bend (Down) + Modulation",
@@ -458,7 +459,6 @@ static std::string addmodlist [] = {
     "FREquency","",
     "PULse",                "pulse width",
     "","",
-//    "SIdeband <s>",         "only sidebands for ring mod (ON, {other})",
     "Volume <n>",           "volume",
     "VElocity <n>",         "velocity sensing sensitivity",
     "Damping <n>",          "higher frequency relative damping",
