@@ -8,7 +8,7 @@
     Copyright 2020 Kristian Amlie
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of the GNU Library General Public
+    it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation; either version 2 of
     the License, or (at your option) any later version.
 
@@ -53,6 +53,7 @@ class LFOParams : public Presets
         void setPrandomness(unsigned char n) { Prandomness = n; presetsUpdated(); }
         void setPfreqrand(unsigned char n) { Pfreqrand = n; presetsUpdated(); }
         void setPdelay(unsigned char n) { Pdelay = n; }
+        void setPbpm(unsigned char n) { Pbpm = n; }
         void setPcontinous(unsigned char n) { Pcontinous = n; presetsUpdated(); }
         void setPstretch(unsigned char n) { Pstretch = n; presetsUpdated(); }
 
@@ -65,6 +66,7 @@ class LFOParams : public Presets
         unsigned char Prandomness;
         unsigned char Pfreqrand;
         unsigned char Pdelay;
+        unsigned char Pbpm;
         unsigned char Pcontinous;
         unsigned char Pstretch;
 
