@@ -171,7 +171,7 @@ string input_text(SynthEngine *synth, string label, string text)
     return synth->getGuiMaster()->setinput(label, text);
 }
 
-//static int keycheck = 0;
+
 void GuiUpdates::read_updates(SynthEngine *synth)
 {
     CommandBlock getData;
@@ -181,33 +181,29 @@ void GuiUpdates::read_updates(SynthEngine *synth)
         decode_updates(synth, &getData);
         Fl::unlock();
     }
+
+    // test refresh time
+    /*
+    static int count = 0;
+    static int toggle = false;
+    ++count;
+    if (count > 30)
+    {
+        count = 0;
+        toggle = !toggle;
+        if (toggle)
+            synth->getRuntime().Log("Tick");
+        else
+            synth->getRuntime().Log("tock");
+    }
+    */
+
     // and pull up to 5 entries from log
     for (int i = 0; !synth->getRuntime().LogList.empty() && i < 5; ++i)
     {
         synth->getGuiMaster()->Log(synth->getRuntime().LogList.front());
         synth->getRuntime().LogList.pop_front();
     }
-    // direct key actions (not for LV2)
-    /*if (!synth->getIsLV2Plugin() && Fl::event_ctrl() && Fl::event_alt() && keycheck == 0)
-    {
-        if (Fl::event_key('H')) // immediate shutdown
-            synth->getGuiMaster()->masterwindow->do_callback();
-        else if (Fl::event_key('R')) // resize to fit
-        {
-            if(!synth->getIsLV2Plugin())
-            for (unsigned int id = 0; id < 31; ++id)
-            {
-                SynthEngine *_synth = synth->getSynthFromId(id);
-                if (_synth != synth)
-                    _synth->getGuiMaster()->rescaleMain();
-            }
-            synth->getGuiMaster()->rescaleMain();
-        }
-        keycheck = 90; // we need this to stop a stream of repeats
-
-    }
-    else if (keycheck > 0)
-        --keycheck;*/
 }
 
 
